@@ -21,29 +21,18 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib.h>
+#include <glibmmconfig.h>
 #include <glibmm/unicode.h>
+#include <glib.h>
 
 #include <iosfwd>
 #include <iterator>
 #include <sstream>
 #include <string>
-
-#include <glibmmconfig.h>
-GLIBMM_USING_STD(bidirectional_iterator_tag)
-GLIBMM_USING_STD(reverse_iterator)
-GLIBMM_USING_STD(string)
-GLIBMM_USING_STD(istream)
-GLIBMM_USING_STD(ostream)
-
-#ifdef GLIBMM_HAVE_STD_ITERATOR_TRAITS
-GLIBMM_USING_STD(iterator_traits)
-#else
+#ifndef GLIBMM_HAVE_STD_ITERATOR_TRAITS
 #include <cstddef> /* for ptrdiff_t */
-GLIBMM_USING_STD(random_access_iterator_tag)
 #endif
 
-
 namespace Glib
 {
 
@@ -255,7 +244,7 @@ public:
   /*! Default constructor, which creates an empty string.
    */
   ustring();
-  
+
   ~ustring();
 
   /*! Construct a ustring as a copy of another ustring.
@@ -265,7 +254,7 @@ public:
 
   /*! Assign the value of another string to this string.
    * @param other A source string.
-   */ 
+   */
   ustring& operator=(const ustring& other);
 
   /*! Swap contents with another string.
@@ -299,19 +288,19 @@ public:
   /*! Construct a ustring as multiple characters.
    * @param n Number of characters.
    * @param uc UCS-4 code point to use.
-   */  
+   */
   ustring(size_type n, gunichar uc);
 
   /*! Construct a ustring as multiple characters.
    * @param n Number of characters.
    * @param c ASCII character to use.
-   */  
+   */
   ustring(size_type n, char c);
 
   /*! Construct a ustring as a copy of a range.
    * @param pbegin Start of range.
    * @param pend End of range.
-   */  
+   */
   template <class In> ustring(In pbegin, In pend);
 
 
@@ -507,7 +496,7 @@ public:
   /** Returns the number of characters in the string, not including any null-termination.
    * @result The number of UTF-8 characters.
    *
-   * @see bytes(), empty() 
+   * @see bytes(), empty()
    */
   size_type size()   const;
 
@@ -516,7 +505,7 @@ public:
   /** This is the same as size().
    */
   size_type length() const;
-  
+
   /** Returns the number of bytes in the string, not including any null-termination.
    * @result The number of bytes.
    *
@@ -609,7 +598,7 @@ public:
 //! @{
 
   /* Returns fmt as is, but checks for invalid references in the format string.
-   * @newin2p18
+   * @newin{2,18}
    */
   template <class T1>
   static inline
@@ -631,21 +620,21 @@ public:
    * @return The substituted message string.
    * @throw Glib::ConvertError
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1>
   static inline
   ustring compose(const ustring& fmt, const T1& a1);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2>
   static inline
   ustring compose(const ustring& fmt, const T1& a1, const T2& a2);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3>
   static inline
@@ -653,7 +642,7 @@ public:
                   const T1& a1, const T2& a2, const T3& a3);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4>
   static inline
@@ -662,7 +651,7 @@ public:
                   const T4& a4);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4, class T5>
   static inline
@@ -671,7 +660,7 @@ public:
                   const T4& a4, const T5& a5);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4, class T5, class T6>
   static inline
@@ -680,7 +669,7 @@ public:
                   const T4& a4, const T5& a5, const T6& a6);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4, class T5, class T6, class T7>
   static inline
@@ -690,7 +679,7 @@ public:
                   const T7& a7);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4,
             class T5, class T6, class T7, class T8>
@@ -701,7 +690,7 @@ public:
                   const T7& a7, const T8& a8);
 
   /* See the documentation for compose(const ustring& fmt, const T1& a1).
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4, class T5,
             class T6, class T7, class T8, class T9>
@@ -739,7 +728,7 @@ public:
    * @return The string representation of the argument stream.
    * @throw Glib::ConvertError
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1>
   static inline
@@ -747,7 +736,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2>
   static inline
@@ -755,7 +744,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3>
   static inline
@@ -763,7 +752,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4>
   static inline
@@ -771,7 +760,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4, class T5>
   static inline
@@ -780,7 +769,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4, class T5, class T6>
   static inline
@@ -789,7 +778,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4,
             class T5, class T6, class T7>
@@ -799,7 +788,7 @@ public:
 
   /* See the documentation for format(const T1& a1).
    *
-   * @newin2p16
+   * @newin{2,16}
    */
   template <class T1, class T2, class T3, class T4,
             class T5, class T6, class T7, class T8>
@@ -818,7 +807,7 @@ private:
   template <class In, class ValueType = typename Glib::IteratorTraits<In>::value_type>
 #endif
   struct SequenceToString;
-  
+
   //The Tru64 compiler needs these partial specializations to be declared here,
   //as well as defined later. That's probably correct. murrayc.
   template <class In> struct SequenceToString<In, char>;
@@ -884,7 +873,12 @@ public:
   ~FormatStream();
 
   template <class T> inline void stream(const T& value);
+
   inline void stream(const char* value);
+
+  //This overload exists to avoid the templated stream() being called for non-const char*.
+  inline void stream(char* value);
+
   ustring to_string() const;
 };
 
@@ -1069,6 +1063,12 @@ void ustring::FormatStream::stream(const char* value)
   stream_ << ustring(value);
 }
 
+inline
+void ustring::FormatStream::stream(char* value)
+{
+  stream_ << ustring(value);
+}
+
 /**** Glib::ustring ********************************************************/
 
 template <class In>
@@ -1273,7 +1273,7 @@ public:
 
 /** A template specialization for Stringify<const char*>,
  * because the regular template has ambiguous constructor overloads for char*.
- */ 
+ */
 template <>
 class ustring::Stringify<const char*>
 {
@@ -1613,4 +1613,3 @@ inline ustring operator+(char lhs, const ustring& rhs)
 
 
 #endif /* _GLIBMM_USTRING_H */
-
